@@ -1,10 +1,5 @@
 
 
-gdal_version <- function() {
-	gdal()
-}
-
-
 gdal <- function(warn=NA, drivers=FALSE) {
 	if (!is.na(warn)) {
 		warn <- as.integer(warn)
