@@ -4,7 +4,7 @@
 # Licence GPL v3
 
 setMethod("ifel", signature(test="SpatRaster"), 
-	function(test, yes, no, filename="", overwrite=FALSE, wopt=list(), ...) {
+	function(test, yes, no, filename="", ...) {
 		if (!inherits(no, "SpatRaster")) {
 			stopifnot(is.numeric(no) || is.logical(no)) # logical includes default NA 
 			if (length(no) > 1) warn("ifel", 'only the first element of "no" is used')
@@ -17,7 +17,7 @@ setMethod("ifel", signature(test="SpatRaster"),
 			if (length(yes) > 1) warn("ifel", 'only the first element of "yes" is used')
 			yes <- classify(test, rbind(c(1, yes[1]), c(0, NA)))
 		}
-		cover(no, yes, value=NA, filename=filename, overwrite=overwrite, wopt=wopt, ...)
+		cover(no, yes, value=NA, filename=filename, ...)
 	}
 )
 
