@@ -86,8 +86,7 @@ setMethod("adjacent", signature(x="SpatVector"),
 )
 
 
-
-setMethod("near", signature(x="SpatVector"), 
+setMethod("nearby", signature(x="SpatVector"), 
 	function(x, distance=0, k=1, centroids=TRUE, symmetrical=TRUE) {
 		if ((geomtype(x) == "polygons") && centroids) {
 			x <- centroids(x)
@@ -96,25 +95,25 @@ setMethod("near", signature(x="SpatVector"),
 			d <- distance(x, pairs=TRUE, symmetrical=symmetrical)
 			d[d[,3] <= distance, 1:2,drop=FALSE]		
 		} else {
-			k <- max(1, min(round(k), nrow(x)))
-			if (k> 1) {
+			k <- max(1, min(round(k), (nrow(x)-1)))
+			if (k > 1) {
 				d <- as.matrix(distance(x, pairs=FALSE))
 				diag(d) <- NA
 				d <- t(apply(d, 1, function(i) order(i)[1:k]))
 				if (k==1) d <- t(d)
-				d <- cbind(id=1:length(x), d)
-				colnames(d)[-1] <- paste0("n", 1:k)
-				d
+				d <- cbind(1:length(x), d)
 			} else {
-			
+				d <- nearest(x)
+				d <- cbind(1:nrow(d), d$to_id)
 			}
+			colnames(d) <- c("id", paste0("k", 1:k))
+			d				
 		}
 	}
 )
 
 
 
-
 setMethod("nearest", signature(x="SpatVector"), 
 	function(x, y, pairs=FALSE, centroids=TRUE, lines=FALSE) {
 		if ((geomtype(x) == "polygons") && centroids) {
@@ -136,24 +135,40 @@ setMethod("nearest", signature(x="SpatVector"),
 			z@ptr <- x@ptr$near_between(y@ptr, pairs)
 		}
 		z <- messages(z, "nearest")
-		if (lines) return(z)
-		
-		dis <- perimeter(z)
-		z <- as.points(z)
-		from <- z[seq(1, nrow(z), 2), ]
-		to <- z[seq(2, nrow(z), 2), ]
-		values(to) <- data.frame(id=1:nrow(to))
-		values(y) <- data.frame(to_id=1:nrow(y))
-		to_int <- as.data.frame(intersect(to, y))
-		if (nrow(to_int) > nrow(to)) {
-			to_int <- aggregate(to_int[, "to_id",drop=FALSE], to_int[,"id",drop=FALSE], function(x)x[1]) 
+		if (geomtype(z) == "points") { #lonlat points
+			if (lines) {
+				x <- z[,c(2,5), drop=T]
+				y <- z[,c(3,6), drop=T]
+				geom <- cbind(rep(1:nrow(x), each=2), 1, as.vector(t(x)), as.vector(t(y)))
+				zz <- vect(geom, "lines", crs=crs(z))
+				values(zz) <- values(z)
+				zz$to_id = zz$to_id + 1
+				zz$from_id = zz$from_id + 1
+				return(zz)
+			} else {
+				z$from_id = z$from_id + 1
+				z$to_id = z$to_id + 1
+				return(z)
+			}
+		} else {
+			if (lines) return(z)
+			dis <- perimeter(z)
+			z <- as.points(z)
+			from <- z[seq(1, nrow(z), 2), ]
+			to <- z[seq(2, nrow(z), 2), ]
+			values(to) <- data.frame(id=1:nrow(to))
+			values(y) <- data.frame(to_id=1:nrow(y))
+			to_int <- as.data.frame(intersect(to, y))
+			if (nrow(to_int) > nrow(to)) {
+				to_int <- aggregate(to_int[, "to_id",drop=FALSE], to_int[,"id",drop=FALSE], function(x)x[1]) 
+			}
+			to_int <- to_int[,2] 
+			from <- geom(from)[, c("x", "y"),drop=FALSE]
+			to <- geom(to)[, c("x", "y"),drop=FALSE]
+			d <- data.frame(1:nrow(from), from, to_int, to, dis)
+			colnames(d) <- c("from_id", "from_x", "from_y", "to_id", "to_x", "to_y", "distance")
+			vect(d, c("to_x", "to_y"), crs=crs(x))
 		}
-		to_int <- to_int[,2] 
-		from <- geom(from)[, c("x", "y"),drop=FALSE]
-		to <- geom(to)[, c("x", "y"),drop=FALSE]
-		d <- data.frame(1:nrow(from), from, to_int, to, dis)
-		colnames(d) <- c("from_id", "from_x", "from_y", "to_id", "to_x", "to_y", "distance")
-		vect(d, c("to_x", "to_y"), crs=crs(x))
 	}
 )
 
