@@ -16,7 +16,11 @@ setMethod("zoom", signature(x="SpatRaster"),
 		if (new) { 
 			grDevices::dev.new() 
 		}
-		x <- crop(x[[layer]], e)
+		if (!is.null(RGB(x))) {
+			x <- crop(x, e)
+		} else {
+			x <- crop(x[[layer]], e)		
+		}
 		plot(x, maxcell=maxcell, ...) 
 		return(invisible(e))
 	}
