@@ -4,4 +4,5 @@ std::vector<std::vector<std::string>> sdinfo(std::string fname);
 std::vector<std::string> get_metadata(std::string filename);
 std::vector<std::string> get_metadata_sds(std::string filename);
 std::vector<std::vector<std::string>> parse_metadata_sds(std::vector<std::string> meta);
-
+void getGDALdriver(std::string &filename, std::string &driver);
+bool getNAvalue(GDALDataType gdt, double & naval);
