@@ -18,6 +18,8 @@
 #ifndef VECMATH_GUARD
 #define VECMATH_GUARD
 
+#include <functional>
+#include <string>
 #include <type_traits>
 #include <vector>
 #include "NA.h"
@@ -25,6 +27,10 @@
 
 
 
+bool haveFun(std::string fun);
+std::function<double(std::vector<double>&, bool)> getFun(std::string fun);
+
+
 template <typename T>
 std::vector<T> flatten(const std::vector<std::vector<T>>& v) {
     std::size_t total_size = 0;
@@ -59,9 +65,10 @@ static inline std::vector<double> vquantile(std::vector<double> v, const std::ve
         [](const double& value) { return std::isnan(value); }),
         std::end(v));
 
-	if ((!narm) & (v.size() < n)) {
-        return std::vector<double>(probs.size(), NAN);
+	if (((!narm) && (v.size() < n)) || (v.size() == 0)) {
+		return std::vector<double>(probs.size(), NAN);
 	}
+
 	n = v.size();
     std::sort(v.begin(), v.end());
 
