@@ -29,9 +29,12 @@ bool SpatRaster::writeValuesMem(std::vector<double> &vals, size_t startrow, size
 		return true;
 	} 
 
-	if (source[0].values.size() == 0) {
+	// this seems rather inefficient for most cases 
+	// where values could simply be appended 
+	if (source[0].values.size() == 0) { // && startrow != 0 && startcol != 0) {
 		source[0].values = std::vector<double>(size(), NAN);
 	}
+	
 	size_t nc = ncell();
 	size_t chunk = nrows * ncols;
 
@@ -163,7 +166,7 @@ SpatRaster SpatRaster::writeRaster(SpatOptions &opt) {
 					return out;
 				}
 			}
-			SpatRaster out(fnames, {-1}, {""}, "");
+			SpatRaster out(fnames, {-1}, {""}, false, {});
 			return out;
 		}	
 	} 
@@ -364,26 +367,34 @@ bool SpatRaster::writeStop(){
 //bool SpatRaster::replaceValues(std::vector<double> cells, std::vector<double> _values, int ncols) {
 //}
 
-bool SpatRaster::setValues(std::vector<double> _values) {
-	bool result = false;
+bool SpatRaster::setValues(std::vector<double> &v, SpatOptions &opt) {
 	SpatRaster g = geometry();
+	SpatRasterSource s = g.source[0];
+	s.hasValues = true;
+	s.memory = true;
+	s.names = getNames();
+	s.driver = "memory";
+	setSource(s);
 
-	if (_values.size() == g.size()) {
-
-		SpatRasterSource s = g.source[0];
-		s.values = _values;
-		s.hasValues = true;
-		s.memory = true;
-		s.names = getNames();
-		s.driver = "memory";
-
-		s.setRange();
-		setSource(s);
-		result = true;
+	if (v.size() < g.size()) {
+		*this = init(v, opt);
+		return hasError();
+	} else if (v.size() == g.size()) {
+		if (!canProcessInMemory(opt)) { 
+		// this should be chunked to avoid the copy
+		// but this may still help in some cases
+			source[0].values = v;
+			*this = writeRaster(opt);
+			return true;
+		} else {
+			source[0].values = v;				
+		}
 	} else {
 		setError("incorrect number of values");
+		return false;
 	}
-	return (result);
+	source[0].setRange();
+	return true;
 }
 
 void SpatRaster::setRange() {
